==> nui_form-0.0.48.tar.gz: lib/component/nuif_checkbox.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

typedef CheckBoxChangeListener = void Function(bool checked);

class NUIFCheckboxStyle{
  NUIFCheckboxStyle({
    this.textStyle,
    this.subTextStyle,
    this.secondaryIcon,
    this.primaryIcon,
    this.primaryIconChecked,
    this.secondaryIconChecked,
    this.padding,
    this.textAlign,
    this.subTextAlign
  });

  TextStyle textStyle;
  TextStyle subTextStyle;
  TextAlign textAlign;
  TextAlign subTextAlign;
  EdgeInsets padding;
  Widget secondaryIcon;
  Widget secondaryIconChecked;
  Widget primaryIcon;
  Widget primaryIconChecked;

  Widget getPrimaryIcon(){
    if(primaryIcon != null) return primaryIcon;
    return Icon(Icons.check_box_outline_blank);
  }

  Widget getPrimaryIconChecked(){
    if(primaryIconChecked != null) return primaryIconChecked;
    return Icon(Icons.check_box);
  }
}

class NUIFCheckboxItem extends NUIFormComponent{
  NUIFCheckboxItem({
    @required String inpId,
    double width,
    double height,
    double weight,
    bool enabled: true,
    @required this.selection,
    this.subText,
    this.enabledStyle,
    this.disabledStyle,
    this.checkBoxChangeListener,
    this.selected: false,
    EdgeInsets margin,
    Alignment align,
    this.otherText
  }) : super(inpId: inpId, inpType:ComponentType.CHECKBOX, width: width, height : height, weight: weight, enabled: enabled, margin: margin, align: align);

  NUIFSelection selection;
  String subText;
  CheckBoxChangeListener checkBoxChangeListener;
  NUIFCheckboxStyle enabledStyle;
  NUIFCheckboxStyle disabledStyle;
  bool selected;
  NUIFTextItem otherText;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCheckbox(item: this, allItemSelectListener: allItemSelectListener, allTextChangeListener: allTextChangeListener, key: key);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    map[inpId] = this.formValue ?? (this.selected ? NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: selection.getValue())) : null);
  }

  @override
  bool validate(bool validate){
    return true;
  }

  NUIFormValue getValue(){
    return this.selected ? NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: selection.getValue())) : null;
  }
}

class NUIFCheckbox extends StatefulWidget {
  NUIFCheckbox({@required this.item, this.allItemSelectListener, this.allTextChangeListener, key}): super(key: key);
  final NUIFCheckboxItem item;
  final AllItemSelectListener allItemSelectListener;
  final AllTextChangeListener allTextChangeListener;
  @override
  _NUIFCheckboxState createState() => _NUIFCheckboxState();
}

class _NUIFCheckboxState extends NUIFState<NUIFCheckbox, NUIFCheckboxItem> {
  String _otherTextValue;
  String _otherTextId;

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _bindWithItem(NUIFCheckboxItem item){

    bool isEnabled = item.enabled;
    NUIFCheckboxStyle style = isEnabled ? item.enabledStyle : item.disabledStyle ?? item.enabledStyle;

    final title = Container(
      child: Text(
          widget.item.selection.getCaption(),
          style: style?.textStyle,
          textAlign: style?.textAlign
      ),
      height: 40,
      alignment: Alignment.centerLeft,
    );

//    final subTitle = !NUIDataUtil.isNullOrEmpty(widget.item.subText) ? Text(
//        widget.item.subText,
//        style: style?.subTextStyle,
//        textAlign: style?.subTextAlign
//    ) : null;

    final checkButton = SizedBox(
      width: 40,
      height: 40,
      child: IconButton(
        icon: item.selected == true ? style?.getPrimaryIconChecked() ?? Icon(Icons.check_box) : style?.getPrimaryIcon() ?? Icon(Icons.check_box_outline_blank),
        enableFeedback: item.enabled,
        onPressed: (){
          if(!item.enabled) return;

          setState(() {
            item.selected = !item.selected;
            item.selection?.selected = item.selected;
            final checked = item.selected;
            if (item.checkBoxChangeListener != null) {
              item.checkBoxChangeListener(checked);
            }
            item.selected = checked;
            if(checked){
              NUIFormValue value = item.formValue ?? NUIFormValue(inpId: item.inpId);
              value.value = NUIFormSelection(value: _otherTextValue ?? item.selection.getCaption(), code: item.selection.getValue());
              item.formValue = value;
            }
            else{
              item.formValue = null;
            }
            widget.allItemSelectListener(item.inpId, NUIFormSelection(value: item.selection.getCaption(), code: item.selection.getValue()), checked);
          });
        },
      ),
    );

    final children = List<Widget>();
    if(style?.secondaryIcon != null && style?.secondaryIconChecked != null){
      children.add(item.selected ? style.secondaryIconChecked : style.secondaryIcon);
    }
    children.add(title);
    children.add(checkButton);

    item.otherText?.enabled = item.selected == true;
    item.otherText?.onChanged = (value){
      _otherTextValue = value;
      _otherTextId = item.inpId ?? item.selection?.getId();
    };

    return NUIRow(
      children: [
        checkButton,
        item.otherText == null ? title :
        SizedBox(
          width: item.otherText.width ?? 120,
          child: NUIColumn(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              title,
              item.otherText.toWidget(allTextChangeListener: widget.allTextChangeListener)
            ],
          ),
        )
      ],
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
    );

//    return Row(
//      children: children,
//      mainAxisSize: MainAxisSize.min,
//      crossAxisAlignment: CrossAxisAlignment.center,
//    );
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_bindWithItem(item));
  }
}

==> nui_form-0.0.49.tar.gz: lib/component/nuif_checkbox.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';

typedef CheckBoxChangeListener = void Function(bool checked);

class NUIFCheckboxStyle{
  NUIFCheckboxStyle({
    this.textStyle,
    this.subTextStyle,
    this.secondaryIcon,
    this.primaryIcon,
    this.primaryIconChecked,
    this.secondaryIconChecked,
    this.padding,
    this.textAlign,
    this.subTextAlign
  });

  TextStyle textStyle;
  TextStyle subTextStyle;
  TextAlign textAlign;
  TextAlign subTextAlign;
  EdgeInsets padding;
  Widget secondaryIcon;
  Widget secondaryIconChecked;
  Widget primaryIcon;
  Widget primaryIconChecked;

  Widget getPrimaryIcon(){
    if(primaryIcon != null) return primaryIcon;
    return Icon(Icons.check_box_outline_blank);
  }

  Widget getPrimaryIconChecked(){
    if(primaryIconChecked != null) return primaryIconChecked;
    return Icon(Icons.check_box);
  }
}

class NUIFCheckboxItem extends NUIFormComponent{
  NUIFCheckboxItem({
    @required String inpId,
    double width,
    double height,
    double weight,
    bool enabled: true,
    @required this.selection,
    this.subText,
    this.enabledStyle,
    this.disabledStyle,
    this.checkBoxChangeListener,
    this.selected: false,
    EdgeInsets margin,
    Alignment align,
    this.otherText
  }) : super(inpId: inpId, inpType:ComponentType.CHECKBOX, width: width, height : height, weight: weight, enabled: enabled, margin: margin, align: align);

  NUIFSelection selection;
  String subText;
  CheckBoxChangeListener checkBoxChangeListener;
  NUIFCheckboxStyle enabledStyle;
  NUIFCheckboxStyle disabledStyle;
  bool selected;
  NUIFTextItem otherText;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCheckbox(item: this, allItemSelectListener: allItemSelectListener, allTextChangeListener: allTextChangeListener, key: key);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    map[inpId] = this.formValue ?? (this.selected ? NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: selection.getValue())) : null);
  }

  @override
  bool validate(bool quiet){
    if(!quiet && stateGetter != null){
      stateGetter().update(this);
    }
    return otherText?.validate(validate) ?? true;
  }

  NUIFormValue getValue(){
    return this.selected ? NUIFormValue(inpId: inpId, value: NUIFormSelection(code: inpId, value: selection.getValue())) : null;
  }
}

class NUIFCheckbox extends StatefulWidget {
  NUIFCheckbox({@required this.item, this.allItemSelectListener, this.allTextChangeListener, key}): super(key: key);
  final NUIFCheckboxItem item;
  final AllItemSelectListener allItemSelectListener;
  final AllTextChangeListener allTextChangeListener;
  @override
  _NUIFCheckboxState createState() => _NUIFCheckboxState();
}

class _NUIFCheckboxState extends NUIFState<NUIFCheckbox, NUIFCheckboxItem> {
  String _otherTextValue;
  String _otherTextId;

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _bindWithItem(NUIFCheckboxItem item){

    bool isEnabled = item.enabled;
    NUIFCheckboxStyle style = isEnabled ? item.enabledStyle : item.disabledStyle ?? item.enabledStyle;

    final title = Container(
      child: Text(
          widget.item.selection.getCaption(),
          style: style?.textStyle,
          textAlign: style?.textAlign
      ),
      height: 40,
      alignment: Alignment.centerLeft,
    );

//    final subTitle = !NUIDataUtil.isNullOrEmpty(widget.item.subText) ? Text(
//        widget.item.subText,
//        style: style?.subTextStyle,
//        textAlign: style?.subTextAlign
//    ) : null;

    final checkButton = SizedBox(
      width: 40,
      height: 40,
      child: IconButton(
        icon: item.selected == true ? style?.getPrimaryIconChecked() ?? Icon(Icons.check_box) : style?.getPrimaryIcon() ?? Icon(Icons.check_box_outline_blank),
        enableFeedback: item.enabled,
        onPressed: (){
          if(!item.enabled) return;

          setState(() {
            item.selected = !item.selected;
            item.selection?.selected = item.selected;
            final checked = item.selected;
            if (item.checkBoxChangeListener != null) {
              item.checkBoxChangeListener(checked);
            }
            item.selected = checked;
            if(checked){
              NUIFormValue value = item.formValue ?? NUIFormValue(inpId: item.inpId);
              value.value = NUIFormSelection(value: _otherTextValue ?? item.selection.getCaption(), code: item.selection.getValue());
              item.formValue = value;
            }
            else{
              item.formValue = null;
            }
            widget.allItemSelectListener(item.inpId, NUIFormSelection(value: item.selection.getCaption(), code: item.selection.getValue()), checked);
          });
        },
      ),
    );

    final children = List<Widget>();
    if(style?.secondaryIcon != null && style?.secondaryIconChecked != null){
      children.add(item.selected ? style.secondaryIconChecked : style.secondaryIcon);
    }
    children.add(title);
    children.add(checkButton);

    item.otherText?.enabled = item.selected == true;
    item.otherText?.onChanged = (value){
      _otherTextValue = value;
      _otherTextId = item.inpId ?? item.selection?.getId();
      item.formValue?.value?.value = _otherTextValue;
    };

    return NUIRow(
      children: [
        checkButton,
        item.otherText == null ? title :
        SizedBox(
          width: item.otherText.width ?? 120,
          child: NUIColumn(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              title,
              item.otherText.toWidget(allTextChangeListener: widget.allTextChangeListener)
            ],
          ),
        )
      ],
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
    );

//    return Row(
//      children: children,
//      mainAxisSize: MainAxisSize.min,
//      crossAxisAlignment: CrossAxisAlignment.center,
//    );
  }

  @override
  Widget build(BuildContext context) {
    return item.wrapWidget(_bindWithItem(item));
  }
}
